==> haskell-http-client-0.5.6.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.6.1
id: http-client-0.5.6.1-DSQ8eJPS1kI6DRuwfPV1nA
key: http-client-0.5.6.1-DSQ8eJPS1kI6DRuwfPV1nA
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.MultipartFormData
    Network.HTTP.Client.Internal
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.PublicSuffixList.Lookup
                Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure
abi: 9ccd9c4de08ddb534267b334b1c8fe46
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-client-0.5.6.1
hs-libraries: HShttp-client-0.5.6.1-DSQ8eJPS1kI6DRuwfPV1nA
depends:
    array-0.5.1.1 base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HwS3NhekiJcDT3x6QkJ9Xz containers-0.5.7.1
    cookie-0.4.2.1-Eaw520oF88i8TRHxiosVEx deepseq-1.4.2.0
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    ghc-prim-0.5.0.0 http-types-0.9.1-CqrySqSyfUpJeibsqMm4gL
    mime-types-0.1.0.7-IGNudFuuwMMBpnhWYuIBl8
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
    random-1.1-54KmMHXjttlERYcr1mvsAe
    streaming-commons-0.1.17-2RhPlNIoNU5IoFWI4FKVKo
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.5.7.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.7.0
id: http-client-0.5.7.0-2oq75h5MpX96GWijxg7br2
key: http-client-0.5.7.0-2oq75h5MpX96GWijxg7br2
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.MultipartFormData
    Network.HTTP.Client.Internal
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure
abi: 81bf8a2a733989451bbfb939ebe3c53e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.7.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.7.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-client-0.5.7.0
hs-libraries: HShttp-client-0.5.7.0-2oq75h5MpX96GWijxg7br2
depends:
    array-0.5.1.1 base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb containers-0.5.7.1
    cookie-0.4.2.1-Eaw520oF88i8TRHxiosVEx deepseq-1.4.2.0
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    ghc-prim-0.5.0.0 http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
    mime-types-0.1.0.7-IGNudFuuwMMBpnhWYuIBl8
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
    network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
    random-1.1-54KmMHXjttlERYcr1mvsAe
    streaming-commons-0.1.18-LWHZCkHap5U1b7BVop9xwy
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
